@@ -5,7 +5,7 @@ use Mojo::DOM;
 use Mojo::ByteStream 'b';
 use Mojo::Util qw/secure_compare hmac_sha1_sum/;
 
-our $VERSION = '0.06_3';
+our $VERSION = '0.04';
 
 # Todo:
 # - Make everything async (top priority)
@@ -26,8 +26,6 @@ my $FEED_ENDING_RE = qr{(?i:\.(r(?:ss|df)|atom))$};
 # User Agent Name
 my $UA_NAME = __PACKAGE__ . ' v' . $VERSION;
 
-# Prototypes
-sub _add_topics;
 
 # Register plugin
 sub register {
@@ -394,7 +392,7 @@ sub _discover_sort_links {
       else {
 	return -1;
       };
-    } @$alternate);
+    } values @$alternate);
   };
 
   # Maybe empty ... maybe not
@@ -743,7 +741,7 @@ sub _find_topics {
   # Unify list
   if (@topics > 1) {
     my %topics = map { $_ => 1 } @topics;
-    @topics = sort keys %topics;
+    @topics = keys %topics;
   };
 
   return \@topics;
@@ -1136,7 +1134,7 @@ hub's response message body is returned additionally.
 =head2 pubsub_accept
 
   # Establish callback
-  $app->callback(
+  $mojo->callback(
     pubsub_accept => sub {
       my ($c, $type, $topics) = @_;
 
@@ -1170,7 +1168,7 @@ helper or on registration.
 =head2 pubsub_verify
 
   # Establish callback
-  $app->callback(
+  $mojo->callback(
     pubsub_verify => sub {
       my ($c, $param) = @_;
 
@@ -1198,7 +1196,7 @@ helper or on registration.
 
 =head2 on_pubsub_content
 
-  $app->hook(
+  $mojo->hook(
     on_pubsub_content => sub {
       my ($c, $type, $dom) = @_;
 
@@ -1224,7 +1222,7 @@ of C<source E<gt> link[rel="self"]>.
 
 =head2 before_pubsub_subscribe
 
-  $app->hook(
+  $mojo->hook(
     before_pubsub_subscribe => sub {
       my ($c, $params, $post) = @_;
 
@@ -1244,7 +1242,7 @@ a secret.
 
 =head2 after_pubsub_subscribe
 
-  $app->hook(
+  $mojo->hook(
     after_pubsub_subscribe => sub {
       my ($c, $hub, $params, $status, $body) = @_;
       if ($status !~ /^2/) {
@@ -1265,7 +1263,7 @@ This hook can be used to deal with errors.
 
 =head2 before_pubsub_unsubscribe
 
-  $app->hook(
+  $mojo->hook(
     before_pubsub_unsubscribe => sub {
       my ($c, $params, $post) = @_;
 
@@ -1285,7 +1283,7 @@ This hook can be used to store unsubscription information.
 
 =head2 after_pubsub_unsubscribe
 
-  $app->hook(
+  $mojo->hook(
     after_pubsub_unsubscribe => sub {
       my ($c, $hub, $params, $status, $body) = @_;
       if ($status !~ /^2/) {
@@ -1309,14 +1307,18 @@ This hook can be used to deal with errors.
 The C<examples/> folder contains a full working example application with publishing,
 subscription and discovery logic.
 The example has additional dependencies of L<DBI>, L<DBD::SQLite> and
-L<XML::Loy> (at least v0.13).
+L<XML::Loy> (at least v0.10).
 
 It can be started using the daemon, morbo or hypnotoad,
 and needs to be accessible from the web.
 
   $ perl examples/pubsubapp daemon
 
-=for HTML <br /><div style="text-align: center;"><img src="http://sojolicio.us/images/pubsubhubbub-screenshot.png" alt="PubSubHubbub Example Application" /></div>
+=begin html
+
+<div style="text-align: center;"><img src="http://sojolicio.us/images/pubsubhubbub-screenshot.png" alt="PubSubHubbub Example Application" /></div>
+
+=end html
 
 This example may be a good starting point for your own implementation, especially,
 if you deal with the subscriber part.
